@@ -29,7 +29,9 @@
 setConstructorS3("RspFileProduct", function(pathname=NA, ..., mustExist=TRUE) {
   # Argument 'pathname':
   if (!is.null(pathname) && !is.na(pathname)) {
-    Arguments$getReadablePathname(pathname, mustExist=mustExist);
+    withoutGString({
+      pathname <- Arguments$getReadablePathname(pathname, mustExist=mustExist);
+    })
   }
 
   extend(RspProduct(pathname, ...), "RspFileProduct");
@@ -38,14 +40,28 @@ setConstructorS3("RspFileProduct", function(pathname=NA, ..., mustExist=TRUE) {
 
 setMethodS3("print", "RspFileProduct", function(x, ...) {
   s <- sprintf("%s:", class(x)[1L]);
+
   s <- c(s, sprintf("Pathname: %s", x));
-  s <- c(s, sprintf("File size: %g bytes", file.info(x)$size));
+
+  # File size
+  fileSize <- getFileSize(x, "units");
+  if (!is.na(fileSize)) {
+    fileSizeB <- sprintf("%.0f bytes", getFileSize(x, "numeric"));
+    if (fileSizeB != fileSize) {
+      fileSize <- sprintf("%s (%s)", fileSize, fileSizeB);
+    }
+  }
+  s <- c(s, sprintf("File size: %s", fileSize));
+
   s <- c(s, sprintf("Content type: %s", getType(x)));
+
   md <- getMetadata(x);
   for (key in names(md)) {
     s <- c(s, sprintf("Metadata '%s': '%s'", key, md[[key]]));
   }
+
   s <- c(s, sprintf("Has processor: %s", hasProcessor(x)));
+
   s <- paste(s, collapse="\n");
   cat(s, "\n", sep="");
 }, protected=TRUE)
@@ -65,8 +81,8 @@ setMethodS3("getType", "RspFileProduct", function(object, as=c("text", "IMT"), .
 
   if (is.na(res)) {
     # Infer type from the filename extension?
-    if (isFile(object)) {
-      res <- extentionToIMT(object);
+    if (isFile(object) || isUrl(object)) {
+      res <- extensionToIMT(object);
     }
   }
 
@@ -78,6 +94,38 @@ setMethodS3("getType", "RspFileProduct", function(object, as=c("text", "IMT"), .
 }, protected=TRUE)
 
 
+setMethodS3("getFileSize", "RspFileProduct", function(object, what=c("numeric", "units"), sep="", ...) {
+  # Argument 'what':
+  what <- match.arg(what);
+
+  pathname <- object
+  if (is.null(pathname)) {
+    fileSize <- NA_real_;
+  } else {
+    fileSize <- file.info2(pathname)$size;
+  }
+
+  if (what == "numeric")
+    return(fileSize);
+
+  if (is.na(fileSize))
+    return(fileSize);
+
+  units <- c("bytes", "kB", "MB", "GB", "TB");
+  scale <- 1;
+  for (kk in seq_along(units)) {
+    unit <- units[kk];
+    if (fileSize < 1000)
+      break;
+    fileSize <- fileSize/1024;
+  }
+  fileSize <- sprintf("%.2f %s%s", fileSize, sep, unit);
+  fileSize <- gsub(".00 bytes", " bytes", fileSize, fixed=TRUE);
+
+  fileSize;
+})
+
+
 
 setMethodS3("findProcessor", "RspFileProduct", function(object, ..., verbose=FALSE) {
   # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
@@ -107,7 +155,7 @@ setMethodS3("findProcessor", "RspFileProduct", function(object, ..., verbose=FAL
   fcn <- switch(type,
     # RSP documents:
     # *<ext>.rsp => *.<ext>
-    "application/x-rsp" = compileRsp,
+    "application/x-rsp" = function(...) { compileRsp(..., postprocess=FALSE) },
 
     # LaTeX documents:
     # *.tex => ... => *.pdf
@@ -120,7 +168,7 @@ setMethodS3("findProcessor", "RspFileProduct", function(object, ..., verbose=FAL
 
     # Markdown documents:
     # *.txt => *.html, ...
-    "application/x-asciidoc" = compileAsciiDoc,
+    "application/x-asciidoc" = function(...) { compileAsciiDoc(..., postprocess=FALSE) },
 
     # Sweave Rnw documents:
     # *.Rnw => *.tex
@@ -167,7 +215,10 @@ setMethodS3("findProcessor", "RspFileProduct", function(object, ..., verbose=FAL
     }
     fcn <- function(pathname, ...) {
       # Arguments 'pathname':
-      pathname <- Arguments$getReadablePathname(pathname);
+      withoutGString({
+        pathname <- Arguments$getReadablePathname(pathname);
+      })
+
       pathnameR <- processor(pathname, ...);
       pathnameR <- getAbsolutePath(pathnameR);
       RspFileProduct(pathnameR, attrs=list(metadata=metadata), mustExist=FALSE);
@@ -184,6 +235,12 @@ setMethodS3("findProcessor", "RspFileProduct", function(object, ..., verbose=FAL
 
 ############################################################################
 # HISTORY:
+# 2014-02-07
+# o Now print() for RspFileProduct reports the file size also in units
+#   of kB, MB, GB, etc.
+# o Added getFileSize() for RspFileProduct.  Taken from R.filesets.
+# 2013-12-14
+# o Now getType() for RspFileProduct works also for URLs.
 # 2013-03-29
 # o Added view().
 # 2013-03-25
