@@ -159,7 +159,7 @@ setMethodS3("getCompleteCode", "RspRSourceCodeFactory", function(this, object, .
   minIndent <- function(...) {
     s <- c(...);
     s <- gsub('"\n"', '"\r"', s);
-    s <- unlist(strsplit(s, split="\n", fixed=TRUE));
+    s <- unlist(strsplit(s, split="\n", fixed=TRUE), use.names=FALSE);
     s <- sapply(s, FUN=function(s) gsub('"\r"', '"\n"', s));
     names(s) <- NULL;
 
@@ -233,7 +233,7 @@ setMethodS3("getCompleteCode", "RspRSourceCodeFactory", function(this, object, .
      value <- sprintf('  %s = "%s"', key, value);
      code <- c(code, value);
   }
-  code <- unlist(strsplit(paste(code, collapse=",\n"), split="\n", fixed=TRUE))
+  code <- unlist(strsplit(paste(code, collapse=",\n"), split="\n", fixed=TRUE), use.names=FALSE);
   code <- c('## RSP document metadata', '.rmeta <- list(', code, ');');
   header0 <- paste('    ', code, sep="");
 
@@ -247,6 +247,19 @@ setMethodS3("getCompleteCode", "RspRSourceCodeFactory", function(this, object, .
     ## - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
     ## Local RSP utility functions
     ## - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
+    ## RSP output function
+    rmeta <- function(...) {
+      args <- list(...)
+      if (length(args) == 0) return(.rmeta)
+      names <- names(args)
+      if (length(names) > 0) {
+        for (name in names) .rmeta[[name]] <<- args[[name]]
+      } else {
+        names <- unlist(args, use.names=FALSE)
+        if (length(names) == 1) .rmeta[[names]] else .rmeta[names]
+      }
+    }
+
     ## Look up \'base\' function once (faster)
     .base_paste0 <- base::paste0
     .base_cat <- base::cat
@@ -290,6 +303,9 @@ setMethodS3("getCompleteCode", "RspRSourceCodeFactory", function(this, object, .
 
 ##############################################################################
 # HISTORY:
+# 2013-12-15
+# o Now the code generated by RspRSourceCodeFactory provide the rmeta()
+#   function for getting and setting document metadata.
 # 2013-09-17
 # o Added a footer comment to the generated RSP source code script.
 #   This was done to ease troubleshooting when incomplete scripts are
